==> fourseasons-5.x-0.2.tar.gz: fourseasons/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="de" xml:lang="de">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <stlye type="text/css"></style>
</head>

<body<?php print phptemplate_body_class($sidebar_left, $sidebar_right); ?>>

<div id="pagewrapper" style="margin:auto; width:960px; border:15px solid #ffffff; background-color:#ffffff;">

  <?php
    // this adds the litte font-size and color tryout widget, its just for demostration purpose -> just delete it, its a hacky with including jquery anyways
    include('admin/toggle-style.tpl.php'); 
  ?>


  <div id="headline">
    <?php
      if ($logo || $site_name) {
        print '<a href="'. check_url($base_path) .'" title="'. $site_name .'">';
        if ($logo) {
          print '<img src="'. check_url($logo) .'" alt="'. $site_title .'" id="logo" />';
        }
        print $site_name .'</a>';
      } else {
        print '<div style="clear:both; height:20px;"></div>';
      }
    ?>
  </div>
  
  <?php 
    foreach($primary_links as $key => $value ) {
      if (ereg('active', $key)) {
        $primary_links[$key]['attributes']['class'] = "active";
      }
    } 
  ?>

  <div id="navigation-primary">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php endif; ?>
    <div style="clear:both;"></div>
  </div>

  <div id="navigation-secondary">
        <?php 
          if (isset($secondary_links)) {
            print theme('links', $secondary_links, array('class' => 'links secondary-links'));
          }
          else {
            print '<ul class="links secondary-links"><li style="border:none;">&nbsp;</li></ul>';
          }
        ?>
    <div style="clear:both;"></div>
  </div>

  <div id="header-image"></div>


  <div id="navigation-breadcrumb">
    <?php if ($breadcrumb): print $breadcrumb; endif; ?>
  </div>

  <div style="clear:both;"></div>

  <div id="contentwrapper">
    <?php if ($sidebar_left): ?>
      <div id="sidebar-left" class="sidebar">
          <?php if ($search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
          <?php print $sidebar_left ?>
      </div>
    <?php endif; ?>

    <div id="middle-content">
      <div class="content-padding">
          <?php if ($mission): print '<div id="mission">'. $mission .'</div>'; endif; ?>

          <?php if ($tabs): print '<div id="tabs-wrapper" class="clear-block">'; endif; ?>
          <?php if ($title): print '<h2'. ($tabs ? ' class="with-tabs"' : '') .'>'. $title .'</h2>'; endif; ?>
          <?php if ($tabs): print $tabs .'</div>'; endif; ?>

          <?php if (isset($tabs2)): print $tabs2; endif; ?>

          <?php if ($help): print $help; endif; ?>
          <?php if ($messages): print $messages; endif; ?>
          <?php print $content ?>
          <span class="clear"></span>
          <?php print $feed_icons ?>
          <div id="footer"><?php print $footer_message ?></div> 
          <div style="clear:both;"></div>
      </div>
    </div>

    <?php if ($sidebar_right): ?>
      <div id="sidebar-right" class="sidebar">
        <?php if (!$sidebar_left && $search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
        <?php print $sidebar_right ?>
      </div>
    <?php endif; ?>
  </div>

  <div style="clear:both;"></div>

</div>

<?php print $closure ?>

</body>
</html>

==> fourseasons-5.x-0.3.tar.gz: fourseasons/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="de" xml:lang="de">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <stlye type="text/css"></style>
</head>

<body<?php print phptemplate_body_class($sidebar_left, $sidebar_right); ?>>

<div id="pagewrapper" style="margin:auto; width:960px; border:15px solid #ffffff; background-color:#ffffff;">

  <?php
    // this adds the litte font-size and color tryout widget, its just for demostration purpose -> just delete it, its a hacky with including jquery anyways
    include('admin/toggle-style.tpl.php'); 
  ?>


  <div id="headline">
    <?php
      if ($logo || $site_name) {
        print '<a href="'. check_url($base_path) .'" title="'. $site_name .'">';
        if ($logo) {
          print '<img src="'. check_url($logo) .'" alt="'. $site_title .'" id="logo" />';
        }
        print $site_name .'</a>';
      } else {
        print '<div style="clear:both; height:20px;"></div>';
      }
    ?>
  </div>
  
  <?php 
    foreach($primary_links as $key => $value ) {
      if (ereg('active', $key)) {
        $primary_links[$key]['attributes']['class'] = "active";
      }
    } 
  ?>

  <div id="navigation-primary">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links, array('class' => 'links primary-links')) ?>
        <?php endif; ?>
    <div style="clear:both;"></div>
  </div>

  <div id="navigation-secondary">
        <?php 
          if (!empty($secondary_links)) {
            print theme('links', $secondary_links, array('class' => 'links secondary-links'));
          }
          else {
            print '<ul class="links secondary-links"><li style="border:none;">&nbsp;</li></ul>';
          }
        ?>
    <div style="clear:both;"></div>
  </div>

  <div id="header-image"></div>


  <div id="navigation-breadcrumb">
    <?php if ($breadcrumb): print $breadcrumb; endif; ?>
  </div>

  <div style="clear:both;"></div>

  <div id="contentwrapper">
    <?php if ($sidebar_left): ?>
      <div id="sidebar-left" class="sidebar">
          <?php if ($search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
          <?php print $sidebar_left ?>
      </div>
    <?php endif; ?>

    <div id="middle-content">
      <div class="content-padding">
          <?php if ($mission): print '<div id="mission">'. $mission .'</div>'; endif; ?>

          <?php if ($tabs): print '<div id="tabs-wrapper" class="clear-block">'; endif; ?>
          <?php if ($title): print '<h2'. ($tabs ? ' class="with-tabs"' : '') .'>'. $title .'</h2>'; endif; ?>
          <?php if ($tabs): print $tabs .'</div>'; endif; ?>

          <?php if (isset($tabs2)): print $tabs2; endif; ?>

          <?php if ($help): print $help; endif; ?>
          <?php if ($messages): print $messages; endif; ?>
          <?php print $content ?>
          <span class="clear"></span>
          <?php print $feed_icons ?>
          <div id="footer"><?php print $footer_message ?></div> 
          <div style="clear:both;"></div>
      </div>
    </div>

    <?php if ($sidebar_right): ?>
      <div id="sidebar-right" class="sidebar">
        <?php if (!$sidebar_left && $search_box): ?><div class="block block-theme"><?php print $search_box ?></div><?php endif; ?>
        <?php print $sidebar_right ?>
      </div>
    <?php endif; ?>
  </div>

  <div style="clear:both;"></div>

</div>

<?php print $closure ?>

</body>
</html>
